[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# ID Lookup client library for Python

[![API Version](https://img.shields.io/badge/api-v2.0.0-blue)](https://developer.factset.com/api-catalog/id-lookup-api)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.IDLookup)](https://pypi.org/project/fds.sdk.IDLookup/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

The ID Lookup API is a fuzzy search service that allows users to resolve symbols but are unable to find them elsewhere. The ID Lookup API allows users to search for entities in a wide variety of ways including, but not limited to, tickers, CUSIPs, URLs, a company’s brands, names and descriptions. The API does not require a complete query and will return different lists of results with each additional character, which enables users to iterate and adjust queries to return the desired results. Each search query returns a list of suggestions that can include every entity type offered by the API based on a matching and ranking algorithm.


The API response returns multiple different symbols that map to both internal FactSet identifiers like security or entity IDs as well as external identifiers like exchange tickers, Morningstar symbols and ISINs. This gives users flexibility in mapping identifiers across the FactSet universe.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- SDK version: 0.10.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.IDLookup==0.10.1
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.IDLookup==0.10.1
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.IDLookup
from fds.sdk.IDLookup.api import fact_set_id_lookup_api
from fds.sdk.IDLookup.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.IDLookup.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.IDLookup.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.IDLookup.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = fact_set_id_lookup_api.FactSetIDLookupApi(api_client)
    dataset = "equities" # str | Type of dataset.

    try:
        # Helper endpoint offering a list of supported fields and values to filter a requested dataset.
        # example passing only required values which don't have defaults set
        api_response = api_instance.helper(dataset)

        pprint(api_response)
    except fds.sdk.IDLookup.ApiException as e:
        print("Exception when calling FactSetIDLookupApi->helper: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Helper endpoint offering a list of supported fields and values to filter a requested dataset.
    #     api_response, http_status_code, response_headers = api_instance.helper_with_http_info(dataset)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.IDLookup.ApiException as e:
    #     print("Exception when calling FactSetIDLookupApi->helper: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Helper endpoint offering a list of supported fields and values to filter a requested dataset.
    #     async_result = api_instance.helper_async(dataset)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.IDLookup.ApiException as e:
    #     print("Exception when calling FactSetIDLookupApi->helper: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Helper endpoint offering a list of supported fields and values to filter a requested dataset.
    #     async_result = api_instance.helper_with_http_info_async(dataset)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.IDLookup.ApiException as e:
    #     print("Exception when calling FactSetIDLookupApi->helper: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.IDLookup

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.IDLookup.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.IDLookup

configuration = fds.sdk.IDLookup.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.IDLookup

configuration = fds.sdk.IDLookup.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.IDLookup

configuration = fds.sdk.IDLookup.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/idsearch/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FactSetIDLookupApi* | [**helper**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/FactSetIDLookupApi.md#helper) | **GET** /metadata/fields/list-by-dataset | Helper endpoint offering a list of supported fields and values to filter a requested dataset.
*FactSetIDLookupApi* | [**search**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/FactSetIDLookupApi.md#search) | **POST** /lookup | Search functionality to return tickers, company names, and unique identifiers for FactSet data.


## Documentation For Models

 - [Datasets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/Datasets.md)
 - [ErrorExample](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/ErrorExample.md)
 - [ErrorResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/ErrorResponse.md)
 - [ExcludeObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/ExcludeObject.md)
 - [FieldsObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/FieldsObject.md)
 - [FilterObjects](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/FilterObjects.md)
 - [Filters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/Filters.md)
 - [HelperEndpoint](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/HelperEndpoint.md)
 - [HelperObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/HelperObject.md)
 - [IncludeObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/IncludeObject.md)
 - [LookupObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/LookupObject.md)
 - [LookupRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/LookupRequest.md)
 - [LookupRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/LookupRequestMeta.md)
 - [LookupResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/LookupResponse.md)
 - [LookupResponseMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/LookupResponseMeta.md)
 - [LookupResponseMetaResultCount](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/LookupResponseMetaResultCount.md)
 - [ResponseDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/ResponseDetails.md)
 - [ResponseDetailsUnderlying](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/ResponseDetailsUnderlying.md)
 - [ValuesObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IDLookup/v2/docs/ValuesObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.IDLookup.apis and fds.sdk.IDLookup.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.IDLookup.api.default_api import DefaultApi`
- `from fds.sdk.IDLookup.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.IDLookup
from fds.sdk.IDLookup.apis import *
from fds.sdk.IDLookup.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

